@@ -335,7 +335,7 @@ void ButtonWidget::checkButtonCommand()
             confFileName = "/home/user/.qtirreco/themes/default/buttons/pause/button.conf";
             return;
         }
-        if(fileNameUnPressed.contains("play",Qt::CaseInsensitive))
+        if(fileNameUnPressed == "play" || fileNameUnPressed == "Play" || fileNameUnPressed == "PLAY")
         {
             fileNameUnPressed = "/home/user/.qtirreco/themes/default/buttons/right/unpressed.png";
             fileNamePressed = "/home/user/.qtirreco/themes/default/buttons/right/pressed.png";
