@@ -95,26 +95,9 @@ void CommandChainDlg::process_line(QString line)
     }
     if(raw_flag) {
          if(line.contains("name", Qt::CaseInsensitive)) {
-            QString commandName = line;
-            QString finalCommandName;
-            int lineLength;
-
-            commandName = commandName.trimmed();
-            lineLength = commandName.length();
-
-            for (int i=lineLength;i>0;i--) {
-                if(commandName.at(i).isSpace() == true)
-                     break;
-                if(commandName.at(i).isSpace() == false)
-                     finalCommandName.append(commandName.at(i));
-            }
-            int remoteLength = finalCommandName.length();
-            QString temp;
-            for(int i=1;i<remoteLength;i++) {
-                temp.prepend(finalCommandName.at(i));
-            }
-            finalCommandName = temp;
-            commands.append(finalCommandName);
+            line = line.trimmed();
+            line.remove(0,5);
+            commands.append(line);
          }
     }
     if(line.contains("begin codes", Qt::CaseInsensitive))
