@@ -884,6 +884,12 @@ void QtIrreco::showRemoteButtons()
 
         remoteButton = new QPushButton(this);
         buttonVector->append(remoteButton);
+        if(rn[i].length() >= 12) {
+            const int fontSize = 26 - rn[i].length();
+            if(fontSize >= 7)
+                buttonVector->at(i)->setFont(QFont("sanf-serif",fontSize,0,0));
+            else buttonVector->at(i)->setFont(QFont("sanf-serif",10,0,0));
+        }
         buttonVector->at(i)->setText(rn[i]);
 
         connect(buttonVector->at(i), SIGNAL(clicked()), this, SLOT(changeRemote()));
